@@ -168,14 +168,24 @@ static PyObject *fparser_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     PyObject *tcp_callback = NULL;
     PyObject *udp_callback = NULL;
     PyObject *after_kill_callback = NULL;
+    int skip_id = 0;
+    int skip_ttl = 0;
+    int skip_ack = 0;
+    int skip_seq = 0;
+    int skip_win = 0;
+    int skip_flags = 0;
+    int soft_mem_limit_mb = 0;
 
     static char* argnames[] = {"source", "flow_timeout", "fin_timeout", "filter",
-        "snaplen", "log_level", "is_file", "tcp_callback", "udp_callback", "kill_callback", NULL};
+        "snaplen", "log_level", "is_file", "skip_id", "skip_ttl", "skip_ack",
+        "skip_seq", "skip_win", "skip_flags", "soft_mem_limit",
+        "tcp_callback", "udp_callback", "kill_callback", NULL};
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, "s|iisiiiOOO",
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "s|iisiiiiiiiiiiOOO",
             argnames, &source, &flow_timeout, &fin_timeout,
-            &filter, &snaplen, &log_level, &is_file, &tcp_callback,
-            &udp_callback, &after_kill_callback)) {
+            &filter, &snaplen, &log_level, &is_file, &skip_id, &skip_ttl,
+            &skip_ack, &skip_seq, &skip_win, &skip_flags, &soft_mem_limit_mb,
+            &tcp_callback, &udp_callback, &after_kill_callback)) {
         return NULL;
     }
 
@@ -210,6 +220,16 @@ static PyObject *fparser_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self->udp_flow_callback = NULL;
 
     init_parser(self->parser);
+    self->parser->skip_ack = skip_ack;
+    self->parser->skip_flags = skip_flags;
+    self->parser->skip_id = skip_id;
+    self->parser->skip_seq = skip_seq;
+    self->parser->skip_ttl = skip_ttl;
+    self->parser->skip_win = skip_win;
+    
+    if (soft_mem_limit_mb) {
+        self->parser->soft_mem_limit = soft_mem_limit_mb * 1024 * 1024;
+    }
 
     /* We need to be able to perform async callbacks from C to Python
        and hence we need to cache the fparser Python object somewhere
