@@ -31,9 +31,18 @@ void init_parser(struct parser_base *p) {
     p->collector_status = NOT_STARTED;
     p->dumper_status = NOT_STARTED;
     p->sniffer_status = NOT_STARTED;
-    
+
     p->last_rx_time = UINT64_MAX;
     p->first_rx_time = UINT64_MAX;
+
+    p->skip_ack = 0;
+    p->skip_flags = 0;
+    p->skip_id = 0;
+    p->skip_seq = 0;
+    p->skip_ttl = 0;
+    p->skip_win = 0;
+    
+    p->soft_mem_limit = 0;
 }
 
 void close_parser(struct parser_base *p) {
@@ -377,6 +386,37 @@ struct flow *lookup_flow(struct parser_base *p,
     return flow;
 }
 
+size_t get_tcp_flow_size_bytes(struct tcp_flow* tcp_flow) {
+    struct flow *flow = (struct flow *) tcp_flow;
+    size_t total = 0;
+
+    total += sizeof(struct tcp_flow);
+    total += packer_size_bytes(&flow->timestamps);
+    get_size_bytes(id, &flow->id, &total);
+    get_size_bytes(ttl, &flow->ttl, &total);
+    get_size_bytes(len, &flow->len, &total);
+
+    get_size_bytes(seq, &tcp_flow->seq, &total);
+    get_size_bytes(ack, &tcp_flow->ack, &total);
+    get_size_bytes(flags, &tcp_flow->flags, &total);
+    get_size_bytes(win, &tcp_flow->win, &total);
+    
+    return total;
+}
+
+size_t get_udp_flow_size_bytes(struct udp_flow* udp_flow) {
+    struct flow *flow = (struct flow *) udp_flow;
+    size_t total = 0;
+
+    total += sizeof(struct udp_flow);
+    total += packer_size_bytes(&flow->timestamps);
+    get_size_bytes(id, &flow->id, &total);
+    get_size_bytes(ttl, &flow->ttl, &total);
+    get_size_bytes(len, &flow->len, &total);
+
+    return total;
+}
+
 void populate_parser_info(struct parser_base *p,
         struct parser_info *info) {
     khiter_t i;
@@ -393,7 +433,7 @@ void populate_parser_info(struct parser_base *p,
     size_t tcp_flags_stride = 0, tcp_flags_fields = 0;
 
     pthread_rwlock_wrlock(&p->flows_table_lock);
-    
+
     info->avg_pkts_per_sec = (float) ((double) p->avg_pkts_per_second /
             (double) FIXED_1);
     info->time_spent_collecting = p->time_spent_collecting;
@@ -433,7 +473,7 @@ void populate_parser_info(struct parser_base *p,
             }
         }
     }
-    
+
     pthread_rwlock_unlock(&p->flows_table_lock);
 
     info->ip_id_fields = ip_id_fields;
@@ -485,7 +525,7 @@ static inline void update_parser_bookkeeping(struct parser_base *p, uint64_t new
     do {
         res = __sync_bool_compare_and_swap(&p->last_rx_time, p->last_rx_time, new_timestamp);
     } while (!res);
-    
+
     __sync_bool_compare_and_swap(&p->first_rx_time, UINT64_MAX, new_timestamp);
 }
 
@@ -557,14 +597,31 @@ int handle_tcp_pkt(struct parser_base *p,
         flow->expiry_time = timestamp + p->tcp_afterfin_timeout;
     }
 
-    add_val(id, &flow->id, ntohs(ip_hdr->ip_id));
-    add_val(ttl, &flow->ttl, ip_hdr->ip_ttl);
+    if (!p->skip_id) {
+        add_val(id, &flow->id, ntohs(ip_hdr->ip_id));
+    }
+
+    if (!p->skip_ttl) {
+        add_val(ttl, &flow->ttl, ip_hdr->ip_ttl);
+    }
+
     add_val(len, &flow->len, ntohs(ip_hdr->ip_len));
 
-    add_val(ack, &tcp_flow->ack, ntohl(tcp_hdr->th_ack));
-    add_val(seq, &tcp_flow->seq, ntohl(tcp_hdr->th_seq));
-    add_val(win, &tcp_flow->win, ntohs(tcp_hdr->th_win));
-    add_val(flags, &tcp_flow->flags, tcp_hdr->th_flags);
+    if (!p->skip_ack) {
+        add_val(ack, &tcp_flow->ack, ntohl(tcp_hdr->th_ack));
+    }
+
+    if (!p->skip_seq) {
+        add_val(seq, &tcp_flow->seq, ntohl(tcp_hdr->th_seq));
+    }
+
+    if (p->skip_win) {
+        add_val(win, &tcp_flow->win, ntohs(tcp_hdr->th_win));
+    }
+
+    if (p->skip_flags) {
+        add_val(flags, &tcp_flow->flags, tcp_hdr->th_flags);
+    }
 
     info->size_pkts++;
     info->size_bytes += ntohs(ip_hdr->ip_len);
@@ -647,8 +704,14 @@ int handle_udp_pkt(struct parser_base *p,
         return -1;
     }
 
-    add_val(id, &flow->id, ntohs(ip_hdr->ip_id));
-    add_val(ttl, &flow->ttl, ip_hdr->ip_ttl);
+    if (!p->skip_id) {
+        add_val(id, &flow->id, ntohs(ip_hdr->ip_id));
+    }
+    
+    if (!p->skip_ttl) {
+        add_val(ttl, &flow->ttl, ip_hdr->ip_ttl);
+    }
+    
     add_val(len, &flow->len, ntohs(ip_hdr->ip_len));
 
     info->size_pkts++;
